@@ -5,7 +5,7 @@ use warnings;
 use base qw( Alien::Base );
 
 # ABSTRACT: Find or build m4
-our $VERSION = '0.08'; # VERSION
+our $VERSION = '0.09'; # VERSION
 
 
 sub alien_helper
@@ -29,7 +29,7 @@ Alien::m4 - Find or build m4
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
@@ -44,7 +44,9 @@ From Alien::Base Build.PL
  use Alien:Base::ModuleBuild;
  my $builder = Module::Build->new(
    ...
-   alien_bin_requires => [ 'Alien::m4' ],
+   alien_bin_requires => {
+     'Alien::m4' => '0.07',
+   },
    ...
  );
  $builder->create_build_script;
